USE [master];
GO

IF DATABASEPROPERTYEX (N'DBMaint2008', N'Version') > 0
BEGIN
	ALTER DATABASE [DBMaint2008] SET SINGLE_USER
		WITH ROLLBACK IMMEDIATE;
	DROP DATABASE [DBMaint2008];
END
GO

-- Create the database to use
CREATE DATABASE [DBMaint2008] ON PRIMARY (
    NAME = N'DBMaint2008_data',
    FILENAME = N'D:\SQLskills\DBMaint2008_data.mdf')
LOG ON (
    NAME = N'DBMaint2008_log',
    FILENAME = N'D:\SQLskills\DBMaint2008_log.ldf',
    SIZE = 512KB,
    FILEGROWTH = 1MB);
GO

USE [DBMaint2008];
GO

-- Create a table that will grow very
-- quickly and generate lots of transaction
-- log
CREATE TABLE [BigRows] (
	[c1] INT IDENTITY,
	[c2] CHAR (8000) DEFAULT 'a');
GO

-- Make sure the database is in FULL
-- recovery model
ALTER DATABASE [DBMaint2008] SET RECOVERY FULL;
GO

BACKUP DATABASE [DBMaint2008] TO
	DISK = N'D:\SQLskills\DBMaint2008.bck'
	WITH INIT, STATS;
GO

-- Cause a bunch of log growth
SET NOCOUNT ON;
GO
INSERT INTO [BigRows] DEFAULT VALUES;
GO 30000

-- This will take a while...

-- How many VLFs do we have?
DBCC LOGINFO (N'DBMaint2008');
GO

-- Shrink the log
DBCC SHRINKFILE (2);
GO

-- Backup the log to allow log clearing
BACKUP LOG [DBMaint2008] TO
	DISK = N'D:\SQLskills\DBMaint2008_log.bck'
	WITH STATS;
GO

-- Shrink the log again.. does it go down?
-- If not, do another backup and re-shrink
DBCC SHRINKFILE (2);
GO

-- Now grow it manually and set auto growth
ALTER DATABASE [DBMaint2008]
	MODIFY FILE (
		NAME = N'DBMaint2008_Log',
		SIZE = 100MB,
		FILEGROWTH = 20MB);
GO

-- And check VLFs again
DBCC LOGINFO (N'DBMaint2008');
GO